package org.medra.test;

import java.io.File;
import java.io.FileInputStream;


import org.apache.commons.httpclient.*;
import org.apache.commons.httpclient.methods.*;
import org.apache.commons.httpclient.protocol.*;

public abstract class HTTPSPostXML {


    /**
     *
     * Usage:
     *          java HTTPSPostXML https://mywebserver/ c:\foo.xml
     *
     *  @param args command line arguments
     *                 Argument 0 is a URL to a web server
     *                 Argument 1 is a local filename
     *
     */
    public static void main(String[] args) throws Exception {
    	
        if (args.length != 4) {
            System.out.println("Usage: java HTTPSPostXML <url> <filename> <username> <password>]");
            System.out.println("classpath must contain the commons-httpclient.jar and commons-logging.jar");
            //System.out.println("<loglevel> - one of error, warn, info, debug, trace");
            System.out.println("<url> - the URL to post the file to");
            System.out.println("<filename> - file to post to the URL");
            System.out.println();
            System.exit(1);
        }
		
		//System.setProperty("log4j.configuration", "D:\\JavaProjects\\HandleSystem\\HandleClient\\batch\\log4j.properties");
		
		//System.getProperties().list(System.out);
        // Get target URL
        String strURL = args[0];
        // Get file to be posted
        String strXMLFilename = args[1];
        File input = new File(strXMLFilename);
		
		//Register HTTPS
		
		Protocol.registerProtocol("https", new Protocol("https", new EasySSLProtocolSocketFactory(), 443));
		
		// Prepare HTTPS post
        PostMethod post = new PostMethod(strURL);
		// Tell the POST method to automatically handle authentication. The
        // method will use any appropriate credentials to handle basic
        // authentication requests.  Setting this value to false will cause
        // any request for authentication to return with a status of 401.
        // It will then be up to the client to handle the authentication.
        post.setDoAuthentication( true );
		// Specify content type and encoding
        // If content encoding is not explicitly specified
        // UTF-8 is assumed
        post.setRequestHeader("Content-type", "text/xml; charset=UTF-8");
        
        // Request content will be retrieved directly 
        // from the input stream
        post.setRequestBody(new FileInputStream(input));
        // Per default, the request content needs to be buffered
        // in order to determine its length.
        // Request body buffering can be avoided when
        // = content length is explicitly specified
        // = chunk-encoding is used
        if (input.length() < Integer.MAX_VALUE) {
            post.setRequestContentLength((int)input.length());
        } else {
            post.setRequestContentLength(EntityEnclosingMethod.CONTENT_LENGTH_CHUNKED);
        }
        
		// Get HTTP client
        HttpClient httpclient = new HttpClient();
		// pass our credentials to HttpClient, they will only be used for
        // authenticating to servers with realm "realm" on the host
        // "www.verisign.com", to authenticate against
        // an arbitrary realm or host change the appropriate argument to null.
        httpclient.getState().setAuthenticationPreemptive(true);
		httpclient.getState().setCredentials(null,null,new UsernamePasswordCredentials(args[2], args[3]));
		
        // Execute request
        int result = httpclient.executeMethod(post);
        // Display status code
        System.out.println("Response status code: " + result);
        // Display response
        System.out.println("Response body: ");
        System.out.println(post.getResponseBodyAsString());
        // Release current connection to the connection pool once you are done
        post.releaseConnection();
    }
}